DefaultCredentialProviderBuilder

Struct DefaultCredentialProviderBuilder 

pub struct DefaultCredentialProviderBuilder { /* private fields */ }
Builder for DefaultCredentialProvider.

Use slot(provider) to override a default slot and no_slot() to remove it from the default chain. Call build() to construct the provider.

Implementations

Source

impl DefaultCredentialProviderBuilder

pub fn new() -> Self

Create a new builder with default state.

pub fn with_profile(self, profile: impl Into<String>) -> Self

Select the AWS profile used by all profile-aware provider slots.

The explicit profile is applied to the shared profile, SSO, and process providers that are still enabled. Other settings on those providers are preserved, and slots removed with no_profile(), no_sso(), or no_process() remain removed.

An explicitly selected profile takes precedence over AWS_PROFILE. Slot-level methods called after this method can still replace or remove individual providers.

pub fn env(self, provider: EnvCredentialProvider) -> Self

Override the environment credential provider slot.

pub fn no_env(self) -> Self

Remove the environment credential provider from the chain.

pub fn profile(self, provider: ProfileCredentialProvider) -> Self

Override the profile credential provider slot.

pub fn no_profile(self) -> Self

Remove the profile credential provider from the chain.

pub fn sso(self, provider: SSOCredentialProvider) -> Self

Override the SSO credential provider slot.

pub fn no_sso(self) -> Self

Remove the SSO credential provider from the chain.

pub fn web_identity( self, provider: AssumeRoleWithWebIdentityCredentialProvider, ) -> Self

Override the web-identity credential provider slot.

pub fn no_web_identity(self) -> Self

Remove the web-identity credential provider from the chain.

pub fn process(self, provider: ProcessCredentialProvider) -> Self

Override the external process credential provider slot.

pub fn no_process(self) -> Self

Remove the external process credential provider from the chain.

pub fn ecs(self, provider: ECSCredentialProvider) -> Self

Override the ECS credential provider slot.

pub fn no_ecs(self) -> Self

Remove the ECS credential provider from the chain.

pub fn imds(self, provider: IMDSv2CredentialProvider) -> Self

Override the EC2 IMDSv2 credential provider slot.

pub fn no_imds(self) -> Self

Remove the EC2 IMDSv2 credential provider from the chain.

pub fn build(self) -> DefaultCredentialProvider

Build the DefaultCredentialProvider with the configured options.