StaticCredentialProvider

Struct StaticCredentialProvider 

pub struct StaticCredentialProvider { /* private fields */ }
StaticCredentialProvider provides static AWS credentials.

This provider is used when you have the access key ID and secret access key directly and want to use them without any dynamic loading.

Implementations

Source

impl StaticCredentialProvider

pub fn new(access_key_id: &str, secret_access_key: &str) -> Self

Create a new StaticCredentialProvider with access key ID and secret access key.

pub fn with_session_token(self, token: &str) -> Self

Set the session token.